/*
Плагин клиента.
Пример пользовательских элементов схем в папке html/plugins/client.
Этот пример в папке html/plugins/client/els 

-------------------------------------------------------------------
  Создание и отладка плагинов клиента, если папка html в архиве html.tar.gz
Для iRZR2, iRZ19, HLK7621, HEOHR1.
  Создать или скопировать (например через WinSCP) файлы плагина в папку:
/opt/storage/files/tm_cpps/html/plugins/client/[имя плагина]
  Пример:
/opt/storage/files/tm_cpps/html/plugins/client/els3/els3.js
/opt/storage/files/tm_cpps/html/plugins/client/els3/els3_RU.json
  Остановить и запустить tm_server:
/etc/init.d/tm_serverd stop
/etc/init.d/tm_serverd start
  Файлы плагина будут скопированы из
/opt/storage/files/tm_cpps/html
в
/tmp/tm_cpps/html
  Если нужно изменять и отлаживать плагин, то удобнее делать это в папке
/tmp/tm_cpps/html/plugins/client/els3
  В браузере Chrome есть средство отладки DevTools.
DevTools можно открыть так - контекстное меню страницы / Просмотреть код.
С помощью DevTools понятно и удобно отлаживать els3.js.
Обновления страницы редактора схем в браузере достаточно для применения изменений в els3.js.
В опциях DevTools не забыть включить пункт Disable cache (while DevTools is open).
  Что бы изменения не потерялись после перегрузки, надо не забыть скопировать файлы в папку
/opt/storage/files/tm_cpps/html/plugins/client/els3
  После обновления версии tm_server плагины сохранятся.
Но, возможно, будут несовместимы с новой версией или даже мешать нормальной загрузке клиента и редактора схем.
В этом случае нужно внести изменения в файлы плагинов или удалить или перенести.
После этого остановить и запустить tm_server.
*/
'use strict'

// добавить множество элементов
tm_sch_elset_add( { tp:'els', nm: 'Example', hint:'Example of a user set of elements.\r\nFolder html/plugins/client/els' } );
// добавление файла els.json с переводом (на русский) имени множества элементов
_LOC.locAdd( { pr:'loc', pf:'els', objs:{ ELSETs:tm_elsets() } } );
// пример статического элемента
//Окружность
tm_sch_el_add( {
    tp:'els_circle' //id типа - должно быть уникально
  , set:'els' //множество элементов, в которое добавить
  , nm:'Circle2'    // имя комонента - отображается в редакторе
  , hint:'Circle2.' // описание комонента - отображается в редакторе
  , pars:{ // параметры комонента - отображаются в редакторе
      c:'u'  // Цвет
    , u:'u0' // Напряжение
    , s:1    // Масштаб
    , w:1    // Толщина
    , m:''   // положение на экране
    ,su:''   // Обесточен - сигнал
    ,sz:''   // Заземлен - сигнал
    }
  , vrs:[    // параметры сигналы
    'su'     // Обесточен
   ,'sz'     // Заземлен
   ]
   // изображение - массив объектов (svg элементов)
  , of: [{ type:'circle', cx:0, cy:0, r:10, 'fill-opacity':0 }]
} );
// стрелка
tm_sch_el_add( {
    tp:'els_arrow'
  , set:'els' //множество элементов, в которое добавить
  , nm:'Arrow2'
  , hint:'Arrow2.'
  , pars:{ c:'u', u:'u0', s:1, w:1, m:'',su:'',sz:''}
  , vrs:['su','sz']
  , of: [{ type:'path', path:'M0,-5 L5,5 L-5,5 z' }]
} );
//выключатель
tm_sch_el_add( {
    tp:'els_switch'//id типа - должно быть уникально
  , set:'els' //множество элементов, в которое добавить
  , nm:'Switch'// имя компонента - отображается в редакторе
  , hint:'Switch.'// описание компонента - отображается в редакторе
  , pars:{ // параметры компонента - отображаются в редакторе
      c:'u'  // Цвет
    , u:'u0' // Напряжение
    , s:1    // Масштаб
    , w:1    // Толщина
    , m:''   // положение на экране
    , ns:0   // Нормальное положение
    , tos:10 // Таймаут переключения
    , ss:''  // Положение - сигнал
    , sy:''  // Телеуправление - сигнал
    , tudo:1 // Диалог выполнения
    , tuyn:0 //Дополнительный диалог подтверждения
    , su:''  // Обесточен - сигнал
    , sz:''  // Заземлен - сигнал
    , se:''  // Разблокирован - сигнал
    , mn:1 // контекстное меню элемента
    , mnsy:1 // пункт телеуправление
    , mnss:1 // пункт положение
    , mnsu:1 // пункт Обесточен
    , mnsz:1 // пункт Заземлен
    , mnse:1 // пункт Разблокирован
    , mnhd:1 // пункт Ручной ввод
    , mned:1 // пункт Редактор сигнала
    , mnev:1 // пункт Журнал событий
    , mnbr:1 // пункт Блокировка
    }
  , vrs:[ // параметры сигналы
      'sy'
    , 'ss'
    , 'su'
    , 'sz'
    , 'se'
    ]
  , onof : 'do_onof' // переключение - имя функции
  // изображение состояния отключен
  , of: [{ type:'path', path:'M-4,0 h8 M-2,18 a2,2 0 1,0 4,0 a2,2 0 1,0 -4,0 m2,-1 l10,-14'}]
  // изображение состояния включен
  , on: [{ type:'path', path:'M-4,0 h8 M-2,18 a2,2 0 1,0 4,0 a2,2 0 1,0 -4,0 m2,-1 l0,-17'}]
} );
//лампа из SVG файла
tm_sch_el_add( {
    tp:'els_lampSVG'//id типа - должно быть уникально
  , set:'els' //множество элементов, в которое добавить
  , nm:'LampSVG'// имя компонента - отображается в редакторе
  , hint:'Lamp SVG.'// описание компонента - отображается в редакторе
  , pars:{ // параметры компонента - отображаются в редакторе
//      c:'u'  // Цвет
 //   , u:'u0' // Напряжение
      s:1    // Масштаб
    , w:1    // Толщина
    , m:''   // положение на экране
    , ns:1   // Нормальное положение
//    , tos:10 // Таймаут переключения
    , sy:''  // Телеуправление - сигнал
    , ss:''  // Положение - сигнал
 //   , su:''  // Обесточен - сигнал
 //   , sz:''  // Заземлен - сигнал
 //   , se:''  // Разблокирован - сигнал
    }
  , vrs:[ // параметры сигналы
      'sy'
    , 'ss'
    , 'su'
    , 'sz'
    , 'se'
    ]
  , onof : 'do_onof' // переключение - имя функции
  // изображение состояния отключен
  , of: [{ type:'image', src:'plugins/client/els/lampOff.svg', x:0, y:0, width:50, height:50}]
  // изображение состояния включен
  , on: [{ type:'image', src:'plugins/client/els/lampOn.svg', x:0, y:0, width:50, height:50}]
} );

//лампа из png файла (jpg, ico, bmp)
tm_sch_el_add( {
    tp:'els_lampPNG'//id типа - должно быть уникально
  , set:'els' //множество элементов, в которое добавить
  , nm:'LampPNG'// имя компонента - отображается в редакторе
  , hint:'Lamp from file png, jpg, ico, bmp.'// описание компонента - отображается в редакторе
  , pars:{ // параметры компонента - отображаются в редакторе
//      c:'u'  // Цвет
 //   , u:'u0' // Напряжение
      s:1    // Масштаб
    , w:1    // Толщина
    , m:''   // положение на экране
    , ns:1   // Нормальное положение
//    , tos:10 // Таймаут переключения
    , sy:''  // Телеуправление - сигнал
    , ss:''  // Положение - сигнал
 //   , su:''  // Обесточен - сигнал
 //   , sz:''  // Заземлен - сигнал
 //   , se:''  // Разблокирован - сигнал
    }
  , vrs:[ // параметры сигналы
      'sy'
    , 'ss'
    , 'su'
    , 'sz'
    , 'se'
    ]
  , onof : 'do_onof' // переключение - имя функции
  // изображение состояния отключен
  , of: [{ type:'image', src:'plugins/client/els/lampOff.png', x:0, y:0, width:24, height:24}]
  // изображение состояния включен
  , on: [{ type:'image', src:'plugins/client/els/lampOn.png', x:0, y:0, width:24, height:24}]
} );
// добавление файла els.json с переводом (на русский) имени комонента и описания комонента 
_LOC.locAdd( { pr:'loc', pf:'els', objs:{ ELSTPs:tm_eltps() } } );

//------------------------------------------------------------------------------------------------------
//Пример пользовательских цветов
//Повторяет таблицу цветов АСУ ТП ПС, кроме цвета фона

tmSCH.schColorTabAdd( { nm: 'colorTab1', ln: 'Color table example (do not use)'
  , tab : {
  'fn' : 'rgb(180,180,180)'//Фон
, 'b' : 'rgb(0,0,0)' // точка присоединения ошиновки к сборным шинам
, 'z' : 'rgb(180,250,150)'//205,255,155)'//Заземлено
, 'u0' : 'rgb(255,255,255)'//обесточено//#000000'
, 'u1' : 'rgb(190,190,190)'//
, 'u6' : 'rgb(200,150,100)'//'#339964'
, 'u10' : 'rgb(100,0,100)'//'#333499'
, 'u20' : 'rgb(130,100,50)'//'#aa00aa'
, 'u35' : 'rgb(130,100,50)'//'#aa00aa'
, 'u110' : 'rgb(0,180,200)'//'#ff5555'
, 'u150' : 'rgb(170,150,0)'
, 'u220' : 'rgb(200,200,0)'
, 'u330' : 'rgb(0,140,0)'
, 'u400' : 'rgb(240,150,30)'
, 'u500' : 'rgb(165,15,10)'
, 'u750' : 'rgb(0,0,200)'
, 'u800' : 'rgb(0,0,200)'
, 'u1150' : 'rgb(205,138,255)'
, 'g' : 'rgb(230,70,230)'//Генераторное напряжение всех классов
// технологическое оборудование
, 'm' : 'rgb(220,200,40)' //Маслосистема
, 'o' : 'rgb(0,130,250)' //Воздушная сеть
, 'f' : 'rgb(0,150,0)' //Пожарная и технологическая сеть
//Цветовое отображение телеизмерений
, 'ti' : 'rgb(0,255,0)' //Активная нагрузка, реактивная нагрузка, ток, напряжение
, 'tu' : 'rgb(200,220,170)' //Напряжение на 1 уровне ПТК ГЦУС МЭС
, 'tt' : 'rgb(255,190,0)' //Дата, время, температура, частота тока
, 'tr' : 'rgb(220,150,145)' //Генерация
, 'tp' : 'rgb(150,175,205)' //Перетоки по сечениям
, 'ta' : 'rgb(255,0,0)' //Авария
, 'tw' : 'rgb(255,255,0)' //Перегруз
, 'tn' : 'rgb(255,255,255)' //Недостоверная информация
, 'td' : 'rgb(255,192,0)' //Дипетчерские имена
, 'sel' : 'rgb(255,255,255)' // select
, 'btn' : 'rgb(0,0,0)' // кнопка рамка
, 'btnb' : 'rgb(150,150,150)' // кнопка фон
, 'btnf' : 'rgb(0,0,0)' // кнопка текст
, 'rpn' : 'rgb(0,0,0)' //РПН //colorRPN
, 'onc' : 'rgb(255,0,0)' //Фон включено
, 'ofc' : 'rgb(80,80,80)' //Фон отключено
, 'oncf' : 'rgb(255,255,255)' //Текст включено
, 'ofcf' : 'rgb(100,100,100)' //Текст отключено
, 'emzok' : 'rgb(0,255,0)' //Неблокирует
, 'emzno' : 'rgb(255,0,0)' //Блокирует
, 'fnobj' : 'rgb(222,222,240)' //Фон объекта//@schIMG
, 'noack' : 'rgb(255,255,0)' //не квитирован//@ACKsch
//, '' : 'rgb(,,)' //
} 
} );

// добавление файла els.json с переводом (на русский) имени таблицы цветов
_LOC.locAdd( { pr:'loc', pf:'els', objs:{ colorTab1:__SCH_PARs.colortab.VALs.colorTab1 } } );
