-- Params to JSON
--[[
Сохраняет сигналы (числа) и Rawdata (строки) в файл формата json:
{"PAR1":1,"PAR2":2,"PAR3":4.33,"str1":"text2"}
Читает сигналы из файла после старта.
Данные из файла приоритетные.
Параметры:
- filename (str) - полный путь и имя файла (пример: /tmp/db/pars.json)
]]--
local log = tmsLog() --log file
local dt = tmsDate() -- date
local tms = tmsSigs() -- get and set sigs
local raw = tmsRawData() -- get and set raw datas
local pars = tms.pars() -- get params
local json = tmsNewJsonReader() -- json parser
local attrs = tms.attrs() --константы атрибутов сигналов
local file = tmsFile() --файлы

local VLs = {}
local updated

function tmsWork() --периодически (см. параметр скрипта "Период обновления")
  updPars()
end
function updPars()
  updated = false
  updSig()
  updRaw()
  if not updated then
    return
  end
  local s = ''
  for id,vl in pairs(VLs) do
    if s:len() ~= 0 then
      s = s..'\n, '
    else
      s = s..'\n  '
    end
    s = s..'"'..id..'":'
    local ds = tms.get( id )
    if ds ~= nil then
      s = s..vl
    else
      s = s..'"'..vl..'"'
    end
  end--while
  s = '{'..s..'\n}\n'
  log.TRACE( pars.filename ) 
  log.TRACE( s )
  if not file.fileWrite( pars.filename, s ) then
    log.ERR( 'do not write file '..pars.filename )
  end
end
function updSig()
--прием обновлений входных сигналов
  local ids = tms.news()
  if ids == nil then
    return--нет новых
  end
  local s
  for k,v in pairs(ids) do
    local DS = tms.get( v )
    if DS ~= nil and not isBad( DS ) then -- сохранять и передавать только достоверные сигналы 
      log.DEBUG( function() return v," ",DS.VL," ",DS.ST," ",dt.frm( DS.DT ) end )
      tms.set( v, DS )
      updateValue( v, DS.VL )
    end--if
  end--for
end--updSig

function updRaw()
  local RD = raw.rawRead() -- чтение массива новых raw data {id1:val1,id2:val2,...}
  if RD == nil then
    return --нет новых
  end
  for _,rvl in pairs( RD ) do
    log.DEBUG( rvl.var, " ", rvl.data )
    raw.rawWrite( rvl.var, rvl.data )
    updateValue( rvl.var, rvl.data, true )
  end
end--updRaw

function updateValue( id, vl, isStr )
  if VLs[id] == vl then
    return
  end
  updated = true
  if isStr then
    VLs[id] = ''..vl
  else
    VLs[id] = ''..vl
  end
end

function tmsStart() --после старта
--  local s = '{"PAR1":1,"PAR2":2,"PAR3":4.33,"str1":"text2"}'
  log.TRACE( pars.filename ) 
  local s = file.fileRead( pars.filename )
  if s == nil then
    log.ERR( 'do not read file '..pars.filename )
  else
    log.TRACE( s ) 
    json:jsonOpen( s ) --строку в json parser
--чтение парамтров {"par1":"val1","par2":2}  
    json:beginObject() --{
    local par, val
    while json:hasNext() do --,
      par = json:nextParam() --"par":
      val = json:nextValue() --:"val"
      if json:isString() then
        VLs[par] = val
      else
        VLs[par] = tonumber( val )
      end
    end--while
    json:endObject() --}
    json:jsonClose() --удалить строку из json parser
  end--if
  local curdt = dt.curDate()
  for id,vl in pairs(VLs) do
    log.DEBUG( function() return id..' = '..vl end )--DEBUG
    local ds = tms.get( id )
    if ds ~= nil then
      sigSend( id, vl, curdt )
    else
      raw.rawWrite( id, vl )
      log.TRACE( function() return "<== '"..id.."' :", vl end )
    end
  end--while
end --tmsStart

function tmsStop() --перед остановкой
  updPars()
end --tmsStop

function sigSend( name, val, date ) --передача сигнала
  local ods = {}
  ods.VL = tonumber( val ) -- значение
  ods.ST = 0 --статус
  ods.DT = date --дата
  sigSendDS( name, ods )
end --sigSend
function sigSendDS( name, ods ) --передача сигнала
  tms.set( name, ods ) -- to tm_server
  log.TRACE( "<== '"..name.."' VL:",ods.VL,",ST:",ods.ST,",DT:",ods.DT )
end --sigSend

function isBad( ds )
  if ds.ST&attrs.aBAD ~= 0 then
    return true
  end
  return false
end


