--state control
--[[
 Контроль состояния.
Применять для управления и контроля состояния реле блокировки и др.
 Параметры:
- timeout - таймаут проверки значения сигнала после отправки команды
 Сигналы:
- сигнал-контроля - входной сигнал, который инициирует команду управления.
- команда управления - вЫходной сигнал, который передается устройству.
- сигнал-состояние - входной сигнал, который принят от устройства,
 является реакцией устройства на команду управления.

Сигналы-контроля и команда управления должны иметь одинаковые id.
Сигнал-состояния должен иметь id такой же, но с префиксом s.
Пример:
cигналы-состояния : Status,  Input,  1,  2,  3
команды управления: Status,  Input,  1,  2,  3
cигналы-состояния: sStatus, sInput, s1, s2, s3

 Логика работы:
Скрипт принимает значение сигнала-контроля, например, от логики блокировки.
и отправляет команду управления с таким же значением.
Сигнал команды управления нужно привязать для отправки устройству.
После отправки скрипт ждет таймаут и в цикле проверяет значение
сигнала-состояния (состояние реле блокировки).
Таймаут должен быть такой, что бы устройство успело прислать состояние.
Если сигнал-состояния неравен значению сигнала-контроля
(например модуль блокировки был сброшен по питанию),
то скрипт отправляет команду управления повторно.
--]]

local log = tmsLog() --log file
local dt = tmsDate() --date
local tm = tmsTick() --timer
local tms = tmsSigs() -- get and set sigs
local raw = tmsRawData() -- get and set raw datas
local utils = tmsUtils() -- utils functions
local pars = tms.pars() -- get params
local ret = tms.parseRet() -- parse ret codes 

local DSs = {} --значения
local IDs = {} --id и tick отправки команды
local cur --текущий tick
local timeout = tm.fromMs( pars.timeout )

function tmsWork() --периодически (см. параметр скрипта "Период обновления")
  cur = nil--сброс текущий tick
--прием обновлений входных сигналов
  local ids = tms.news()
  if ids ~= nil then
    inSigs( ids )
  end
  for id,t in pairs(IDs) do
    if t ~= true then
      if cur == nil then
        cur = tm.curTick()  
      end
      if tm.timeout( t, timeout, cur ) then
        t = true
        IDs[id] = true --проверять
      end
    end--if
    if t == true then
      local ds = DSs[id] --команда
      local sds = DSs['s'..id]--состояние
 --     if ds.VL ~= sds.VL or ds.ST ~= sds.ST then
      if ds.VL ~= sds.VL then --221123 атрибут "расчетный" мешает
         sendCmd( id, ds ) --повтор команды
      end
    end--if    
  end--for
end--tmsWork

function tmsStart() --только после старта
  local outIDs = tms.outIDs()
  if outIDs == nil then
    log.ERR( 'добавьте вЫходные сигналы' )
    return
  end
  for k,id in pairs(outIDs) do
    IDs[id] = true
  end--for  
  
  local inIDs = tms.inIDs()
  if inIDs == nil then
    log.ERR( 'добавьте входные сигналы' )
    return
  end
  inSigs( inIDs )
  --[[
  for k,v in pairs(inIDs) do
    local c = v:sub(1,1)
    local id = v:sub(2)
    if c == 's' then
      G.rSigs[id] = 
    end
  end--for
  --]]
end--tmsStart

function tmsStop() --только перед остановкой
end--tmsStop

function inSigs( ids )
--чтение сигналов, ids - массив идентификаторы входных сигналов
  local s = ""
  for k,id in pairs(ids) do
    local ds = tms.get( id )
    if ds ~= nil then
      log.DEBUG( function()
        s = s..' '..id
        return '--> '..id,": ",ds.VL," ",ds.ST," ",dt.frm( ds.DT )
      end )
      DSs[id] = ds
      local c = id:sub(1,1)
      if c ~= 's' then
        sendCmd( id, ds )--команда
      end
    end
  end --for
  log.DEBUG( s )
end-- inSigs

function sendCmd( id, ds )
  if cur == nil then
    cur = tm.curTick()  
  end
  IDs[id] = cur --запомнить тик
  tms.set( id, ds ) --отправить команду
  log.MES( function()
    return '<== '..id,": ",ds.VL," ",ds.ST," ",dt.frm( ds.DT )
  end )
end
